@@ -1,5 +1,3 @@
-from ast import While
-import Adafruit_PWM_Servo_Driver as servo_drv # Adafruit Industries 是纽约的一家开源硬件公司
 import RPi.GPIO as GPIO
 import time
 import sys
