@@ -7,11 +7,8 @@ from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.constants import *
 from tkinter.scrolledtext import ScrolledText
 from pathlib import Path
-import led
+from . import led, acc, servo, joystick
 import passive_buzzer as pbz
-import acc
-import servo
-import joystick
 import PCF8591 as adc
 import ds18b20 as temperature
 # import sys
@@ -242,27 +239,30 @@ class MainGui(ttk.Frame):
         sep = ttk.Separator(v_frm, bootstyle=SECONDARY)
         sep.grid(row=9, column=0, columnspan=3, pady=10, sticky=EW)
 
+
+        h_container = ttk.Frame(left_panel)
+        h_container.pack(fill=X, expand=YES)
         ## stop button
         btn = ttk.Button(
-            master=v_frm, 
+            master=h_container, 
             text='Stop', 
             image='stop-backup-dark', 
             compound=LEFT, 
             command=self.stop, 
             bootstyle=LINK
         )
-        btn.grid(row=10, column=0, columnspan=2, sticky=W)
+        btn.pack(side=LEFT, fill=X, expand=YES) #.grid(row=0, column=0, columnspan=1, sticky=W)
 
         _func = lambda: Messagebox.ok(message='Changing properties')
-        bus_prop_btn = ttk.Button(
-            master=v_frm, 
+        btn = ttk.Button(
+            master=h_container, 
             text='Config', 
             image='properties-dark', 
             compound=LEFT,
             command=_func, 
             bootstyle=LINK
         )
-        bus_prop_btn.grid(row=10, column=2, columnspan=1, sticky=W)
+        btn.pack(side=LEFT, fill=X, expand=YES) #.grid(row=0, column=1, columnspan=1, sticky=W)
 
         ############## STATUS Panel ################
         # status (collapsible)
@@ -527,7 +527,7 @@ class MainGui(ttk.Frame):
 
         # Resize the image using resize() method
         # print(self.winfo_width() , self.winfo_height())
-        resize_image = img.resize((300,200)) # img.resize((self.media.winfo_width() , max(self.media.winfo_height() - 50, 1) ))
+        resize_image = img.resize((240,180)) # img.resize((self.media.winfo_width() , max(self.media.winfo_height() - 50, 1) ))
         imgtk = ImageTk.PhotoImage(resize_image)
 
         return img, imgtk
@@ -618,5 +618,7 @@ if __name__ == '__main__':
     
     app = ttk.Window("Raspi Control Panel")
     app.geometry(DEFAULT_WINSIZE)
+    app.attributes('-fullscreen', True)
+
     MainGui(app)
     app.mainloop()
